@@ -14,26 +14,41 @@ from masonite.providers import (
     BroadcastProvider,
     AuthenticationProvider,
     AuthorizationProvider,
+    HashServiceProvider,
+    ORMProvider,
 )
 
+
+from masonite.scheduling.providers import ScheduleProvider
+from masonite.notification.providers import NotificationProvider
+from masonite.validation.providers import ValidationProvider
+
+from tests.integrations.app.providers import AppProvider
+
 # register local package
 from src.masonite.js_routes import JSRoutesProvider
 
 PROVIDERS = [
     FrameworkProvider,
     HelpersProvider,
-    JSRoutesProvider,
     RouteProvider,
     ViewProvider,
     WhitenoiseProvider,
     ExceptionProvider,
     MailProvider,
+    NotificationProvider,
     SessionProvider,
     CacheProvider,
     QueueProvider,
+    ScheduleProvider,
     EventProvider,
     StorageProvider,
     BroadcastProvider,
+    HashServiceProvider,
     AuthenticationProvider,
+    ValidationProvider,
     AuthorizationProvider,
+    ORMProvider,
+    JSRoutesProvider,
+    AppProvider,
 ]
